#!/usr/bin/env bash

# Copyright 2019 The Skaffold Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set -exu

readonly BASE_URL=${1}

cd docs-v2
mkdir -p themes
ln -s /app/docs/themes/docsy ./themes/docsy
ln -s /app/docs/node_modules ./node_modules

# Hugo was updated to be more strict about shortcodes. 
# to prevent changing existing structure, we will copy over the files before hugo invocation.
mkdir -p layouts/partials/shortcodes
cp -r layouts/shortcodes layouts/partials/

hugo --baseURL=${BASE_URL}
